# hula-0.1.0.0
*First working version.*


### What is hula?

Hula is a set of unconventional machine learning modules. Hula is designed to unify the desired aspects of most machine learning capabilities out there. 

### Documentation

For Hula's documentation visit https://robert-bassett-coder.gitbook.io/workspace/
